# welcome to saturnOS config, run nixos-help if you need it .
{ config, pkgs, lib, ...  }:
{
	imports = [
		./modules
		./system
	];

	# nix options
	nix.settings = {
		experimental-features = "nix-command flakes";
		auto-optimise-store = true;
		trusted-users = [ "root" "@wheel" ];
		trusted-public-keys = [
			"sol.gg.lan-1:Ithqh5H+QslaHf9UPgLS1BVIkpV1Ab7bAEFFBEpTYtE=" 
		];
	};

	# enable gnome
	services.xserver.enable = true;
	services.xserver.displayManager.gdm.enable = true;
	services.xserver.desktopManager.gnome.enable = true;

	# enable dconf configuration for gnome and other supported applications
	programs.dconf.enable = true;

	# configure pipewire
	sound.enable = true;
	hardware.pulseaudio.enable = false;
	security.rtkit.enable = true;
	services.pipewire = {
		enable = true;
		alsa.enable = true;
		alsa.support32Bit = true;
		pulse.enable = true;
		jack.enable = true;
	};

	# install packages
	# `nix search` to add more
	nixpkgs.config.allowUnfree = true;
	nixpkgs.config.nvidia.acceptLicense = true;
nixpkgs.config.permittedInsecurePackages = [ "electron-24.8.6" ];

	environment.systemPackages = with pkgs; [
	];

	# set fish as default shell for all users
	users.defaultUserShell = pkgs.fish;

	# suid wrapper ( for things which need privelidged acccess, or additional configuration )
	programs.gnupg.agent = {
		enable = true;
		enableSSHSupport = true;
		pinentryFlavor = "gnome3";
	};
	programs.fish.enable = true;

	# enable configure services
	services.printing.enable = true;	# printing
	services.openssh.enable = true;	# remote shell
}
